LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.std_logic_unsigned.all;
USE ieee.numeric_std.ALL;
 
ENTITY tb_full_design IS
END tb_full_design;
 
ARCHITECTURE behavior OF tb_full_design IS 
 
    -- Component Declaration for the Unit Under Test (UUT)
 
component rs232monitor_v2 is
    Port ( clk_i 			: in  	STD_LOGIC;
           rst_i 			: in  	STD_LOGIC;
           RXD_i 			: in  	STD_LOGIC;
			  TXD_o 			: out  	STD_LOGIC;
			  SW_i  			: in 		STD_LOGIC_VECTOR(7 downto 0);
           led7_an_o 	: out  	STD_LOGIC_VECTOR (3 downto 0);
           led7_seg_o 	: out  	STD_LOGIC_VECTOR (7 downto 0);
			  led_o			: out  	STD_LOGIC_VECTOR (7 downto 0));
end component;   

   --Inputs
   signal clk_i : std_logic := '0';
   signal rst_i : std_logic := '0';
   signal RXD_i : std_logic := '0';
	signal TXD_o : std_logic := '0';
	
   signal SW_i : std_logic_vector(7 downto 0) := "00001111"; -- set for test of 230400bps

 	--Outputs
   signal led7_an_o : std_logic_vector(3 downto 0);
   signal led7_seg_o : std_logic_vector(7 downto 0);

   -- Clock period definitions
   constant clk_i_period : time := 20 ns;
	constant RXD_i_period : time := 4.34 us; -- period set for test of 230400bps 
	signal   DATA_TB: std_logic_vector(7 downto 0):=x"23"; -- initial RXD_i input data
 
BEGIN
 
	-- Instantiate the Unit Under Test (UUT)
   uut: rs232monitor_v2 PORT MAP (
          clk_i => clk_i,
          rst_i => rst_i,
          RXD_i => RXD_i,
			 TXD_o => TXD_o,
          SW_i => SW_i,
          led7_an_o => led7_an_o,
          led7_seg_o => led7_seg_o
        );

    -- Clock process definitions
   clk_i_process :process
   begin
		clk_i <= '0';
		wait for clk_i_period/2;
		clk_i <= '1';
		wait for clk_i_period/2;
   end process;

	rst_i <= '1', '0' after 52 ns;
   
	RXD_i_process :process
   begin
		RXD_i <= '1';
		wait for RXD_i_period;
		RXD_i <= '0';
		wait for RXD_i_period;
		RXD_i <= DATA_TB(0);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(1);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(2);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(3);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(4);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(5);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(6);
		wait for RXD_i_period;
		RXD_i <= DATA_TB(7);
		wait for RXD_i_period;
		RXD_i <= '1';
		wait for RXD_i_period;-- *5;
		DATA_TB <= DATA_TB +1; -- changes input data after each run
   end process;
 

END;
